"use strict";
/*
 *
 * Copyright 2018-present NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BlockHeaderTable = exports.CommandOptions = void 0;
const Table = require("cli-table3");
const clime_1 = require("clime");
const symbol_sdk_1 = require("symbol-sdk");
const profile_command_1 = require("../../interfaces/profile.command");
const profile_options_1 = require("../../interfaces/profile.options");
const height_resolver_1 = require("../../resolvers/height.resolver");
const formatter_service_1 = require("../../services/formatter.service");
class CommandOptions extends profile_options_1.ProfileOptions {
}
__decorate([
    (0, clime_1.option)({
        flag: 'h',
        description: 'Block height.',
    }),
    __metadata("design:type", String)
], CommandOptions.prototype, "height", void 0);
exports.CommandOptions = CommandOptions;
class BlockHeaderTable {
    constructor(blockInfo) {
        this.blockInfo = blockInfo;
        this.table = new Table({
            style: { head: ['cyan'] },
            head: ['Property', 'Value'],
        });
        this.table.push(['Record Id:', blockInfo.recordId], ['Hash:', blockInfo.hash], ['Generation Hash:', blockInfo.generationHash], ['Total Fee:', blockInfo.totalFee.toString()], ['Number of Transactions:', blockInfo.transactionsCount], ['Number of Transactions (with embedded):', blockInfo.totalTransactionsCount], ['Signature:', blockInfo.signature.slice(0, 64) + '\n' + blockInfo.signature.slice(64, 128)], ['Signer:', blockInfo.signer.publicKey], ['Network Type:', symbol_sdk_1.NetworkType[blockInfo.networkType]], ['Version:', blockInfo.version], ['Type:', blockInfo.type], ['Height:', blockInfo.height.toString()], ['Timestamp:', blockInfo.timestamp.toString()], ['Difficulty:', blockInfo.difficulty.toString()], ['Fee Multiplier:', blockInfo.feeMultiplier], ['Previous Block Hash:', blockInfo.previousBlockHash], ['Block Transactions Hash:', blockInfo.blockTransactionsHash], ['Block Receipts Hash:', blockInfo.blockReceiptsHash], ['State Hash:', blockInfo.stateHash]);
        if (blockInfo.beneficiaryAddress) {
            this.table.push(['Beneficiary Address', blockInfo.beneficiaryAddress.pretty()]);
        }
    }
    toString() {
        let text = '';
        text += formatter_service_1.FormatterService.title('Block Header');
        text += '\n' + this.table.toString();
        return text;
    }
}
exports.BlockHeaderTable = BlockHeaderTable;
let default_1 = class default_1 extends profile_command_1.ProfileCommand {
    constructor() {
        super();
    }
    async execute(options) {
        const profile = this.getProfile(options);
        const height = await new height_resolver_1.HeightResolver().resolve(options);
        this.spinner.start();
        const blockHttp = profile.repositoryFactory.createBlockRepository();
        blockHttp.getBlockByHeight(height).subscribe((blockInfo) => {
            this.spinner.stop();
            console.log(new BlockHeaderTable(blockInfo).toString());
        }, (err) => {
            this.spinner.stop();
            console.log(formatter_service_1.FormatterService.error(err));
        });
    }
};
__decorate([
    clime_1.metadata,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [CommandOptions]),
    __metadata("design:returntype", Promise)
], default_1.prototype, "execute", null);
default_1 = __decorate([
    (0, clime_1.command)({
        description: 'Get block header by height',
    }),
    __metadata("design:paramtypes", [])
], default_1);
exports.default = default_1;
