"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MosaicAddressRestrictionsTable = exports.CommandOptions = void 0;
/*
 *
 * Copyright 2018-present NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
const Table = require("cli-table3");
const clime_1 = require("clime");
const rxjs_1 = require("rxjs");
const operators_1 = require("rxjs/operators");
const symbol_sdk_1 = require("symbol-sdk");
const profile_command_1 = require("../../interfaces/profile.command");
const profile_options_1 = require("../../interfaces/profile.options");
const address_resolver_1 = require("../../resolvers/address.resolver");
const mosaic_resolver_1 = require("../../resolvers/mosaic.resolver");
const formatter_service_1 = require("../../services/formatter.service");
class CommandOptions extends profile_options_1.ProfileOptions {
}
__decorate([
    (0, clime_1.option)({
        flag: 'a',
        description: 'Account address.',
    }),
    __metadata("design:type", String)
], CommandOptions.prototype, "address", void 0);
__decorate([
    (0, clime_1.option)({
        flag: 'm',
        description: 'Mosaic id in hexadecimal format.',
    }),
    __metadata("design:type", String)
], CommandOptions.prototype, "mosaicId", void 0);
exports.CommandOptions = CommandOptions;
class MosaicAddressRestrictionsTable {
    constructor(mosaicAddressRestrictions) {
        this.mosaicAddressRestrictions = mosaicAddressRestrictions;
        this.table = new Table({
            style: { head: ['cyan'] },
            head: ['Type', 'Value'],
        });
        mosaicAddressRestrictions.forEach((mosaicRestriction) => {
            mosaicRestriction.restrictions.forEach((value) => {
                this.table.push(['Key', value.key.toString()], ['Value', value.restrictionValue.toString()]);
            });
        });
    }
    toString() {
        let text = '';
        text += formatter_service_1.FormatterService.title('Mosaic Address Restrictions');
        text += '\n' + this.table.toString();
        return text;
    }
}
exports.MosaicAddressRestrictionsTable = MosaicAddressRestrictionsTable;
let default_1 = class default_1 extends profile_command_1.ProfileCommand {
    constructor() {
        super();
    }
    async execute(options) {
        const profile = this.getProfile(options);
        const address = await new address_resolver_1.AddressResolver().resolve(options, profile);
        const mosaicId = await new mosaic_resolver_1.MosaicIdResolver().resolve(options);
        this.spinner.start();
        const restrictionHttp = profile.repositoryFactory.createRestrictionMosaicRepository();
        // Should we load all?
        const criteria = { mosaicId, targetAddress: address };
        const observable = restrictionHttp.search(criteria).pipe((0, operators_1.mergeMap)((page) => {
            return (0, rxjs_1.from)(page.data);
        }), (0, operators_1.filter)((m) => m instanceof symbol_sdk_1.MosaicAddressRestriction), (0, operators_1.map)((m) => m), (0, operators_1.toArray)());
        observable.subscribe((mosaicRestrictions) => {
            this.spinner.stop();
            if (mosaicRestrictions.length > 0) {
                console.log(new MosaicAddressRestrictionsTable(mosaicRestrictions).toString());
            }
            else {
                console.log(formatter_service_1.FormatterService.error('The address does not have mosaic address restrictions assigned'));
            }
        }, (err) => {
            this.spinner.stop();
            console.log(formatter_service_1.FormatterService.error(err));
        });
    }
};
__decorate([
    clime_1.metadata,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [CommandOptions]),
    __metadata("design:returntype", Promise)
], default_1.prototype, "execute", null);
default_1 = __decorate([
    (0, clime_1.command)({
        description: 'Fetch mosaic restrictions assigned to an address',
    }),
    __metadata("design:paramtypes", [])
], default_1);
exports.default = default_1;
