"use strict";
/*
 *
 * Copyright 2018-present NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommandOptions = void 0;
const clime_1 = require("clime");
const symbol_sdk_1 = require("symbol-sdk");
const announce_transactions_command_1 = require("../../interfaces/announce.transactions.command");
const announce_transactions_options_1 = require("../../interfaces/announce.transactions.options");
const options_resolver_1 = require("../../options-resolver");
const amount_resolver_1 = require("../../resolvers/amount.resolver");
const divisibility_resolver_1 = require("../../resolvers/divisibility.resolver");
const duration_resolver_1 = require("../../resolvers/duration.resolver");
const maxFee_resolver_1 = require("../../resolvers/maxFee.resolver");
const mosaic_resolver_1 = require("../../resolvers/mosaic.resolver");
class CommandOptions extends announce_transactions_options_1.AnnounceTransactionsOptions {
}
__decorate([
    (0, clime_1.option)({
        flag: 'a',
        description: 'Initial supply of mosaics.',
    }),
    __metadata("design:type", String)
], CommandOptions.prototype, "amount", void 0);
__decorate([
    (0, clime_1.option)({
        flag: 't',
        description: '(Optional) Mosaic transferable.',
        toggle: true,
    }),
    __metadata("design:type", Object)
], CommandOptions.prototype, "transferable", void 0);
__decorate([
    (0, clime_1.option)({
        flag: 's',
        description: '(Optional) Mosaic supply mutable.',
        toggle: true,
    }),
    __metadata("design:type", Object)
], CommandOptions.prototype, "supplyMutable", void 0);
__decorate([
    (0, clime_1.option)({
        flag: 'r',
        description: '(Optional) Mosaic restrictable.',
        toggle: true,
    }),
    __metadata("design:type", Object)
], CommandOptions.prototype, "restrictable", void 0);
__decorate([
    (0, clime_1.option)({
        flag: 'd',
        description: 'Mosaic divisibility, from 0 to 6.',
    }),
    __metadata("design:type", Number)
], CommandOptions.prototype, "divisibility", void 0);
__decorate([
    (0, clime_1.option)({
        flag: 'u',
        description: 'Mosaic duration in amount of blocks.',
    }),
    __metadata("design:type", String)
], CommandOptions.prototype, "duration", void 0);
__decorate([
    (0, clime_1.option)({
        flag: 'n',
        description: '(Optional) Mosaic non-expiring.',
        toggle: true,
    }),
    __metadata("design:type", Object)
], CommandOptions.prototype, "nonExpiring", void 0);
exports.CommandOptions = CommandOptions;
let default_1 = class default_1 extends announce_transactions_command_1.AnnounceTransactionsCommand {
    constructor() {
        super();
    }
    async execute(options) {
        const profile = this.getProfile(options);
        const account = await this.getSigningAccount(profile, options);
        const nonce = symbol_sdk_1.MosaicNonce.createRandom();
        let blocksDuration;
        if (!(await (0, options_resolver_1.OptionsConfirmResolver)(options, 'nonExpiring', 'Do you want a non-expiring mosaic?'))) {
            blocksDuration = await new duration_resolver_1.DurationResolver().resolve(options);
        }
        const divisibility = await new divisibility_resolver_1.DivisibilityResolver().resolve(options);
        const mosaicFlags = await new mosaic_resolver_1.MosaicFlagsResolver().resolve(options);
        const amount = await new amount_resolver_1.AmountResolver().resolve(options, 'Amount of mosaics units to create: ');
        const maxFee = await new maxFee_resolver_1.MaxFeeResolver().resolve(options);
        const multisigSigner = await this.getMultisigSigner(options);
        const signerAddress = multisigSigner ? multisigSigner.info.accountAddress : account.address;
        const mosaicDefinition = symbol_sdk_1.MosaicDefinitionTransaction.create(symbol_sdk_1.Deadline.create(profile.epochAdjustment), nonce, symbol_sdk_1.MosaicId.createFromNonce(nonce, signerAddress), mosaicFlags, divisibility, blocksDuration ? blocksDuration : symbol_sdk_1.UInt64.fromUint(0), profile.networkType);
        const mosaicSupplyChange = symbol_sdk_1.MosaicSupplyChangeTransaction.create(symbol_sdk_1.Deadline.create(profile.epochAdjustment), mosaicDefinition.mosaicId, symbol_sdk_1.MosaicSupplyChangeAction.Increase, amount, profile.networkType);
        const signatureOptions = {
            account,
            transactions: [mosaicDefinition, mosaicSupplyChange],
            maxFee,
            multisigSigner,
            isAggregate: true,
            isAggregateBonded: signerAddress.plain() !== account.address.plain(),
        };
        const signedTransactions = await this.signTransactions(signatureOptions, options);
        this.announceTransactions(options, signedTransactions);
    }
};
__decorate([
    clime_1.metadata,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [CommandOptions]),
    __metadata("design:returntype", Promise)
], default_1.prototype, "execute", null);
default_1 = __decorate([
    (0, clime_1.command)({
        description: 'Create a new mosaic',
    }),
    __metadata("design:paramtypes", [])
], default_1);
exports.default = default_1;
