"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommandOptions = void 0;
/*
 *
 * Copyright 2018-present NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
const clime_1 = require("clime");
const symbol_sdk_1 = require("symbol-sdk");
const announce_transactions_command_1 = require("../../interfaces/announce.transactions.command");
const announce_transactions_options_1 = require("../../interfaces/announce.transactions.options");
const address_resolver_1 = require("../../resolvers/address.resolver");
const key_resolver_1 = require("../../resolvers/key.resolver");
const maxFee_resolver_1 = require("../../resolvers/maxFee.resolver");
const mosaic_resolver_1 = require("../../resolvers/mosaic.resolver");
const restrictionValue_resolver_1 = require("../../resolvers/restrictionValue.resolver");
class CommandOptions extends announce_transactions_options_1.AnnounceTransactionsOptions {
}
__decorate([
    (0, clime_1.option)({
        flag: 'm',
        description: 'Mosaic identifier or @alias being restricted.',
    }),
    __metadata("design:type", String)
], CommandOptions.prototype, "mosaicId", void 0);
__decorate([
    (0, clime_1.option)({
        flag: 'a',
        description: 'Address or @alias being restricted.',
    }),
    __metadata("design:type", String)
], CommandOptions.prototype, "targetAddress", void 0);
__decorate([
    (0, clime_1.option)({
        flag: 'k',
        description: 'Restriction key.',
    }),
    __metadata("design:type", String)
], CommandOptions.prototype, "restrictionKey", void 0);
__decorate([
    (0, clime_1.option)({
        flag: 'V',
        description: 'New restriction value.',
    }),
    __metadata("design:type", String)
], CommandOptions.prototype, "newRestrictionValue", void 0);
exports.CommandOptions = CommandOptions;
let default_1 = class default_1 extends announce_transactions_command_1.AnnounceTransactionsCommand {
    constructor() {
        super();
    }
    async execute(options) {
        const profile = this.getProfile(options);
        const account = await this.getSigningAccount(profile, options);
        const mosaicId = await new mosaic_resolver_1.MosaicIdAliasResolver().resolve(options);
        const targetAddress = await new address_resolver_1.UnresolvedAddressResolver().resolve(options, undefined, 'Enter the restricted target address or @alias:', 'targetAddress');
        const restrictionKey = await new key_resolver_1.KeyResolver().resolve(options, undefined, 'restrictionKey');
        const restrictionValue = await new restrictionValue_resolver_1.RestrictionValueResolver().resolve(options);
        const maxFee = await new maxFee_resolver_1.MaxFeeResolver().resolve(options);
        const multisigSigner = await this.getMultisigSigner(options);
        const repositoryFactory = profile.repositoryFactory;
        const restrictionMosaicHttp = repositoryFactory.createRestrictionMosaicRepository();
        const namespaceHttp = repositoryFactory.createNamespaceRepository();
        const mosaicRestrictionTransactionService = new symbol_sdk_1.MosaicRestrictionTransactionService(restrictionMosaicHttp, namespaceHttp);
        const mosaicAddressRestrictionTransaction = await mosaicRestrictionTransactionService
            .createMosaicAddressRestrictionTransaction(symbol_sdk_1.Deadline.create(profile.epochAdjustment), profile.networkType, mosaicId, restrictionKey, targetAddress, restrictionValue, maxFee)
            .toPromise();
        const signatureOptions = {
            account,
            transactions: [mosaicAddressRestrictionTransaction],
            maxFee,
            multisigSigner,
        };
        const signedTransactions = await this.signTransactions(signatureOptions, options);
        this.announceTransactions(options, signedTransactions);
    }
};
__decorate([
    clime_1.metadata,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [CommandOptions]),
    __metadata("design:returntype", Promise)
], default_1.prototype, "execute", null);
default_1 = __decorate([
    (0, clime_1.command)({
        description: 'Set a mosaic restriction to an specific address (requires internet)',
    }),
    __metadata("design:paramtypes", [])
], default_1);
exports.default = default_1;
