"use strict";
/*
 *
 * Copyright 2018-present NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommandOptions = void 0;
const clime_1 = require("clime");
const symbol_sdk_1 = require("symbol-sdk");
const announce_transactions_command_1 = require("../../interfaces/announce.transactions.command");
const announce_transactions_options_1 = require("../../interfaces/announce.transactions.options");
const address_resolver_1 = require("../../resolvers/address.resolver");
const amount_resolver_1 = require("../../resolvers/amount.resolver");
const duration_resolver_1 = require("../../resolvers/duration.resolver");
const hashAlgorithm_resolver_1 = require("../../resolvers/hashAlgorithm.resolver");
const maxFee_resolver_1 = require("../../resolvers/maxFee.resolver");
const mosaic_resolver_1 = require("../../resolvers/mosaic.resolver");
const secret_resolver_1 = require("../../resolvers/secret.resolver");
class CommandOptions extends announce_transactions_options_1.AnnounceTransactionsOptions {
}
__decorate([
    (0, clime_1.option)({
        description: 'Locked mosaic identifier or @alias.',
        flag: 'm',
    }),
    __metadata("design:type", String)
], CommandOptions.prototype, "mosaicId", void 0);
__decorate([
    (0, clime_1.option)({
        description: 'Amount of mosaic units to lock.',
        flag: 'a',
    }),
    __metadata("design:type", String)
], CommandOptions.prototype, "amount", void 0);
__decorate([
    (0, clime_1.option)({
        description: 'Number of blocks for which a lock should be valid. ' +
            'Duration is allowed to lie up to 30 days. If reached, the mosaics will be returned to the initiator.',
        flag: 'd',
    }),
    __metadata("design:type", String)
], CommandOptions.prototype, "duration", void 0);
__decorate([
    (0, clime_1.option)({
        description: 'Proof hashed in hexadecimal format.',
        flag: 's',
    }),
    __metadata("design:type", String)
], CommandOptions.prototype, "secret", void 0);
__decorate([
    (0, clime_1.option)({
        description: 'Algorithm used to hash the proof (Op_Sha3_256, Op_Hash_160, Op_Hash_256).',
        flag: 'H',
    }),
    __metadata("design:type", String)
], CommandOptions.prototype, "hashAlgorithm", void 0);
__decorate([
    (0, clime_1.option)({
        description: 'Address or @alias that receives the funds once unlocked.',
        flag: 'r',
    }),
    __metadata("design:type", String)
], CommandOptions.prototype, "recipientAddress", void 0);
exports.CommandOptions = CommandOptions;
let default_1 = class default_1 extends announce_transactions_command_1.AnnounceTransactionsCommand {
    constructor() {
        super();
    }
    async execute(options) {
        const profile = this.getProfile(options);
        const account = await this.getSigningAccount(profile, options);
        const mosaicId = await new mosaic_resolver_1.MosaicIdAliasResolver().resolve(options, 'Enter the locked mosaic identifier or alias:');
        const amount = await new amount_resolver_1.AmountResolver().resolve(options, 'Enter the absolute amount of mosaic units to lock:');
        const recipientAddress = await new address_resolver_1.UnresolvedAddressResolver().resolve(options, undefined, 'Enter the address (or @alias) that receives the funds once unlocked:', 'recipientAddress');
        const duration = await new duration_resolver_1.DurationResolver().resolve(options, 'Enter the number of blocks for which a lock should be valid:');
        const secret = await new secret_resolver_1.SecretResolver().resolve(options);
        const hashAlgorithm = await new hashAlgorithm_resolver_1.HashAlgorithmResolver().resolve(options);
        const maxFee = await new maxFee_resolver_1.MaxFeeResolver().resolve(options);
        const transaction = symbol_sdk_1.SecretLockTransaction.create(symbol_sdk_1.Deadline.create(profile.epochAdjustment), new symbol_sdk_1.Mosaic(mosaicId, amount), duration, hashAlgorithm, secret, recipientAddress, profile.networkType, maxFee);
        const multisigSigner = await this.getMultisigSigner(options);
        const signatureOptions = {
            account,
            transactions: [transaction],
            maxFee,
            multisigSigner,
        };
        const signedTransactions = await this.signTransactions(signatureOptions, options);
        this.announceTransactions(options, signedTransactions);
    }
};
__decorate([
    clime_1.metadata,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [CommandOptions]),
    __metadata("design:returntype", Promise)
], default_1.prototype, "execute", null);
default_1 = __decorate([
    (0, clime_1.command)({
        description: 'Announce a secret lock transaction',
    }),
    __metadata("design:paramtypes", [])
], default_1);
exports.default = default_1;
