"use strict";
/*
 *
 * Copyright 2018-present NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.AggregateTypeResolver = void 0;
const symbol_sdk_1 = require("symbol-sdk");
const options_resolver_1 = require("../options-resolver");
const aggregateType_validator_1 = require("../validators/aggregateType.validator");
/**
 * Aggregate type resolver
 */
class AggregateTypeResolver {
    /**
     * Resolves a aggregate type provided by the user.
     * @param {Options} options - Command options.
     * @param {string} altText - Alternative text.
     * @param {string} altKey - Alternative key.
     * @returns {Promise<number>}
     */
    async resolve(options, altText, altKey) {
        const choices = [
            { title: 'AGGREGATE_BONDED', value: symbol_sdk_1.TransactionType.AGGREGATE_BONDED },
            { title: 'AGGREGATE_COMPLETE', value: symbol_sdk_1.TransactionType.AGGREGATE_COMPLETE },
        ];
        const value = +(await (0, options_resolver_1.OptionsChoiceResolver)(options, altKey ? altKey : 'aggregateType', altText ? altText : 'Choose an aggregate type:', choices, 'select', new aggregateType_validator_1.AggregateTypeValidator()));
        return value;
    }
}
exports.AggregateTypeResolver = AggregateTypeResolver;
