"use strict";
/*
 *
 * Copyright 2018-present NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.MultisigAccountModificationView = void 0;
const symbol_sdk_1 = require("symbol-sdk");
class MultisigAccountModificationView {
    /**
     * Creates an instance of MultisigAccountModificationView.
     * @param {MultisigAccountModificationTransaction} tx
     */
    constructor(tx) {
        this.tx = tx;
    }
    /**
     * @static
     * @param {MultisigAccountModificationTransaction} tx
     * @returns {CellRecord}
     */
    static get(tx) {
        return new MultisigAccountModificationView(tx).render();
    }
    /**
     * @private
     * @returns {CellRecord}
     */
    render() {
        return {
            'Min approval delta': `${this.tx.minApprovalDelta}`,
            'Min removal delta': `${this.tx.minRemovalDelta}`,
            ...this.getModifications(),
        };
    }
    /**
     * @private
     * @returns {CellRecord}
     */
    getModifications() {
        return {
            ...this.renderModifications(symbol_sdk_1.CosignatoryModificationAction.Add),
            ...this.renderModifications(symbol_sdk_1.CosignatoryModificationAction.Remove),
        };
    }
    /**
     * @private
     * @param {CosignatoryModificationAction} type
     * @returns {CellRecord}
     */
    renderModifications(type) {
        const targetProperty = type === symbol_sdk_1.CosignatoryModificationAction.Add ? 'addressAdditions' : 'addressDeletions';
        const targetPropertyName = type === symbol_sdk_1.CosignatoryModificationAction.Add ? 'Address addition' : 'Address deletion';
        const modifications = this.tx[targetProperty];
        const modificationNumber = modifications.length;
        if (modificationNumber === 0) {
            return {};
        }
        const getKey = (index) => `${targetPropertyName} (${index + 1} / ${modificationNumber})`;
        return modifications.reduce((acc, address, index) => ({
            ...acc,
            [getKey(index)]: address instanceof symbol_sdk_1.Address ? address.pretty() : address.toHex(),
        }), {});
    }
}
exports.MultisigAccountModificationView = MultisigAccountModificationView;
