"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommandOptions = void 0;
/*
 *
 * Copyright 2018-present NEM
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
const clime_1 = require("clime");
const symbol_sdk_1 = require("symbol-sdk");
const announce_transactions_command_1 = require("../../interfaces/announce.transactions.command");
const announce_transactions_options_1 = require("../../interfaces/announce.transactions.options");
const options_resolver_1 = require("../../options-resolver");
const cosignature_resolver_1 = require("../../resolvers/cosignature.resolver");
const formatter_service_1 = require("../../services/formatter.service");
const transaction_view_1 = require("../../views/transactions/details/transaction.view");
class CommandOptions extends announce_transactions_options_1.AnnounceTransactionsOptions {
}
__decorate([
    (0, clime_1.option)({
        flag: 'P',
        description: 'Transaction payload to be announced (hex string).',
    }),
    __metadata("design:type", String)
], CommandOptions.prototype, "payload", void 0);
__decorate([
    (0, clime_1.option)({
        flag: 'c',
        description: 'Cosignatures json array to be added (e.g. ["cosig1","cosig2"]).',
    }),
    __metadata("design:type", String)
], CommandOptions.prototype, "cosignatures", void 0);
exports.CommandOptions = CommandOptions;
let default_1 = class default_1 extends announce_transactions_command_1.AnnounceTransactionsCommand {
    constructor() {
        super();
    }
    async execute(options) {
        this.options = options;
        this.profile = this.getProfile(this.options);
        const txPayload = await (0, options_resolver_1.OptionsResolver)(options, 'payload', () => undefined, 'Enter the transaction payload (hex string):', 'text', undefined);
        const transaction = symbol_sdk_1.TransactionMapping.createFromPayload(txPayload);
        console.log(formatter_service_1.FormatterService.success('Transaction loaded:'));
        new transaction_view_1.TransactionView(transaction, undefined, this.profile).print();
        let cosignatures = [];
        if (transaction.type === symbol_sdk_1.TransactionType.AGGREGATE_COMPLETE) {
            cosignatures = await new cosignature_resolver_1.CosignatureResolver().resolve(options);
            if (cosignatures) {
                console.log('Cosignatures added:', JSON.stringify(cosignatures));
            }
            else {
                console.log('No cosignatures added.');
                cosignatures = [];
            }
        }
        const txHash = symbol_sdk_1.Transaction.createTransactionHash(txPayload, Array.from(symbol_sdk_1.Convert.hexToUint8(this.profile.networkGenerationHash)));
        const signedTransactionWithSignatures = this.signTransactionGivenSignatures(txPayload, txHash, transaction.signer.publicKey, transaction.type, this.profile.networkType, cosignatures);
        new transaction_view_1.TransactionView(transaction, signedTransactionWithSignatures, this.profile).print();
        await this.announceTransactions(options, [signedTransactionWithSignatures]);
    }
    signTransactionGivenSignatures(signedPayload, transactionHash, signerPublicKey, transactionType, networkType, cosignatureSignedTransactions) {
        if (cosignatureSignedTransactions && cosignatureSignedTransactions.length > 0) {
            cosignatureSignedTransactions.forEach((cosignedTransaction) => {
                signedPayload += cosignedTransaction.version.toHex() + cosignedTransaction.signerPublicKey + cosignedTransaction.signature;
            });
            // Calculate new size
            const size = `00000000${(signedPayload.length / 2).toString(16)}`;
            const formatedSize = size.substr(size.length - 8, size.length);
            const littleEndianSize = formatedSize.substr(6, 2) + formatedSize.substr(4, 2) + formatedSize.substr(2, 2) + formatedSize.substr(0, 2);
            signedPayload = littleEndianSize + signedPayload.substr(8, signedPayload.length - 8);
        }
        return new symbol_sdk_1.SignedTransaction(signedPayload, transactionHash, signerPublicKey, transactionType, networkType);
    }
};
__decorate([
    clime_1.metadata,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [CommandOptions]),
    __metadata("design:returntype", Promise)
], default_1.prototype, "execute", null);
default_1 = __decorate([
    (0, clime_1.command)({
        description: 'Announce a transaction payload (with cosignatures if the type is aggregate complete)',
    }),
    __metadata("design:paramtypes", [])
], default_1);
exports.default = default_1;
